@@ -2,10 +2,10 @@
 from __future__ import annotations
 
 import dataclasses
-import sys
 from pathlib import Path
 from typing import Iterator
 from typing import List
+from typing import Literal
 from typing import Optional
 from typing import Tuple
 
@@ -18,11 +18,6 @@ from rich.table import Table
 
 from nbpreview.component import row
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
 
 def _pick_option(option: Optional[bool], detector: bool) -> bool:
     """Select a render option.
@@ -63,13 +58,17 @@ def _get_output_pad(plain: bool) -> Tuple[int, int, int, int]:
 
 
 def _pick_image_drawing(
-    option: Literal["block", None], is_terminal: bool, plain: bool, unicode: bool
-) -> Literal["block", None]:
+    option: Literal["block", "character", "braille", None],
+    is_terminal: bool,
+    plain: bool,
+    unicode: bool,
+) -> Literal["block", "character", "braille", None]:
     """Pick an image render option.
 
     Args:
-        option (Literal["block", None]): The inputted option which can
-            override detections. If None, will autodetect.
+        option (Literal["block", "character", "braille", None]): The
+            inputted option which can override detections. If None, will
+            autodetect.
         is_terminal (bool): Whether the program is being used in a
             terminal.
         plain (bool): Whether to render the image in a plain style. Will
@@ -79,7 +78,7 @@ def _pick_image_drawing(
             render the notebook. By default will autodetect.
 
     Returns:
-        Literal["block", None]: The image type to render.
+        Literal["block", "character", "braille", None]: The image type to render.
     """
     image_render = option
     if option is None and is_terminal and not plain:
@@ -100,7 +99,9 @@ def _render_notebook(
     hide_output: bool,
     language: str,
     images: bool,
-    image_drawing: Literal["block", None],
+    image_drawing: Literal["block", "character", "braille", None],
+    color: bool,
+    negative_space: bool,
 ) -> Table:
     """Create a table representing a notebook."""
     grid = table.Table.grid(padding=(1, 1, 1, 0))
@@ -135,6 +136,8 @@ def _render_notebook(
                 theme=theme,
                 images=images,
                 image_drawing=image_drawing,
+                color=color,
+                negative_space=negative_space,
             )
             for rendered_output in rendered_outputs:
                 grid.add_row(*rendered_output.to_table_row())
@@ -180,10 +183,12 @@ class Notebook:
     hide_output: bool = False
     nerd_font: bool = False
     files: bool = True
+    negative_space: bool = True
     hyperlinks: Optional[bool] = None
     hide_hyperlink_hints: bool = False
     images: Optional[bool] = None
-    image_drawing: Optional[Literal["block"]] = None
+    image_drawing: Optional[Literal["block", "character", "braille"]] = None
+    color: Optional[bool] = None
 
     def __post_init__(self) -> None:
         """Constructor."""
@@ -206,7 +211,7 @@ class Notebook:
         hyperlinks: Optional[bool] = None,
         hide_hyperlink_hints: bool = False,
         images: Optional[bool] = None,
-        image_drawing: Literal["block", None] = None,
+        image_drawing: Literal["block", "character", "braille", None] = None,
     ) -> Notebook:
         """Create Notebook from notebook file."""
         notebook_node = nbformat.read(file, as_version=4)
@@ -243,13 +248,13 @@ class Notebook:
         )
         hyperlinks = _pick_option(self.hyperlinks, detector=options.legacy_windows)
         images = _pick_option(self.images, detector=not options.is_terminal)
+        color = _pick_option(self.color, detector=not options.is_terminal)
         image_drawing = _pick_image_drawing(
             self.image_drawing,
             is_terminal=options.is_terminal,
             plain=plain,
             unicode=unicode,
         )
-
         rendered_notebook = _render_notebook(
             self.cells,
             plain=plain,
@@ -263,5 +268,7 @@ class Notebook:
             language=self.language,
             images=images,
             image_drawing=image_drawing,
+            color=color,
+            negative_space=self.negative_space,
         )
         yield rendered_notebook
